@@ -1,20 +1,30 @@
-
-module SpecInfra
+module Specinfra
   module Backend
     class Lxc < Exec
+      def initialize(config = {})
+        super
+
+        begin
+          require 'lxc/extra' unless defined?(::LXC::Extra)
+        rescue LoadError
+          fail "LXC client library is not available. Try installing `lxc-extra' gem"
+        end
+      end
+
       def run_command(cmd, opts={})
         cmd = build_command(cmd)
         cmd = add_pre_command(cmd)
         out, ret = ct.execute do
-                     out = `#{cmd}`
-                     [out, $?.dup]
-                   end
+          out = `#{cmd}  2>&1`
+          [out, $?.dup]
+        end
         if @example
           @example.metadata[:command] = cmd
           @example.metadata[:stdout]  = out
         end
         CommandResult.new :stdout => out, :exit_status => ret.exitstatus
       end
+
       def build_command(cmd)
         cmd
       end
@@ -23,17 +33,12 @@ module SpecInfra
         cmd
       end
 
-      def copy_file(from, to)
-        begin
-          FileUtils.cp(from, File.join(ct.config_item('lxc.rootfs'), to))
-        rescue => e
-          return false
-        end
-        true
+      def send_file(from, to)
+        FileUtils.cp(from, File.join(ct.config_item('lxc.rootfs'), to))
       end
 
       def ct
-        @ct ||= ::LXC::Container.new(RSpec.configuration.lxc)
+        @ct ||= ::LXC::Container.new(get_config(:lxc))
       end
     end
   end
