@@ -5,18 +5,25 @@ class Specinfra::Command::Freebsd::Base::File < Specinfra::Command::Base::File
       "stat -f%Sg #{escape(file)} | grep -- #{escape(regexp)}"
     end
 
+    def get_owner_group(file)
+      "stat -f%Sg #{escape(file)}"
+    end
+
     def check_is_owned_by(file, owner)
       regexp = "^#{owner}$"
       "stat -f%Su #{escape(file)} | grep -- #{escape(regexp)}"
     end
 
+    def get_owner_user(file)
+      "stat -f%Su #{escape(file)}"
+    end
+
     def check_has_mode(file, mode)
-      regexp = "^#{mode}$"
-      "stat -f%Lp #{escape(file)} | grep -- #{escape(regexp)}"
+      "test `stat -f%Mp%Lp #{escape(file)} | sed 's/^0*//'` -eq #{escape(mode)}"
     end
 
     def get_mode(file)
-      "stat -f%Lp #{escape(file)}"
+      "stat -f%Mp%Lp #{escape(file)} | sed 's/^0*//'"
     end
 
     def check_is_linked_to(link, target)
